@@ -39,13 +39,15 @@ def _ensure_SSH():
         origin_url = gitflow.get('remote.' + gitflow_origin + '.url')
     except Exception:
         raise RemoteNotFound(
-                "Please configure git remote '{0}' before proceesing further." \
+                "Please configure git remote '{0}' before proceeding further." \
                         .format(gitflow_origin))
     if re.match('(https?://|git://)', origin_url):
         raise IllegalCommunicationProtocol("Only SSH remotes are supported.")
     if origin_url.startswith('ssh://'):
         origin_url = origin_url[6:].replace('/', ':', 1)
-        CoreGitFlow().git.remote('set-url', gitflow_origin, origin_url)
+    if not origin_url.endswith('.git'):
+        origin_url += '.git'
+    CoreGitFlow().git.remote('set-url', gitflow_origin, origin_url)
 
 class GitFlow(CoreGitFlow):
 
@@ -131,7 +133,7 @@ def _ask_config(args, name, question):
         print question +':', default_suggestion
         answer = default_suggestion
     else:
-        answer = raw_input(question + '? [' + default_suggestion + '] ')
+        answer = raw_input(question + '? [' + str(default_suggestion) + '] ')
         answer = answer.strip() or default_suggestion
         if answer == '-':
             answer = ''
@@ -219,6 +221,12 @@ def run_default(args):
     _ask_name(args, 'release.versionmatcher',
             'Regular expression for matching release numbers')
 
+    _ask_name(args, 'circleci.enabled',
+            'Enable Circle CI integration [Y/n]')
+
+    _ask_name(args, 'pagination',
+            'Number of stories to list on one page')
+
     _ask_pt_projid(args.use_defaults)
     _ask_pt_labels(args.use_defaults)
     _ask_rb_repoid(args.use_defaults)
